from django.db import models


class Article(models.Model):
    title = models.CharField(
        max_length=200, null=False, blank=False, verbose_name='Заголовок',
    )
    text = models.TextField(
        null=False, blank=False, verbose_name='Текст',
    )
    author = models.CharField(
        max_length=40, null=False, blank=False, default='Неизвестный автор', 
        verbose_name='Автор',
    )
    created_at = models.DateTimeField(auto_now_add=True, verbose_name='Дата создания')
    updated_at = models.DateTimeField(auto_now=True, verbose_name='Дата обновления')

    class Meta:
        verbose_name = 'статья'
        verbose_name_plural = 'статьи'

    def __str__(self):
        return f'{self.id} {self.title}'


class Comment(models.Model):
    article = models.ForeignKey(
        'webapp.Article',
        related_name='comments',
        on_delete=models.CASCADE,
        verbose_name='Статья'
    )
    text = models.TextField(max_length=400, verbose_name='Текст')
    author = models.CharField(max_length=40, blank=True, default='Аноним', verbose_name='Автор')
    created_at = models.DateTimeField(auto_now_add=True, verbose_name='Дата создания')
    updated_at = models.DateTimeField(auto_now=True, verbose_name='Дата обновления')

    def __str__(self):
        return self.text[:20]
